pub trait NodeWrapper: Copy + Into<NodeIndex> {
// Provided methods
fn input_stores(
self,
graph: &Graph,
) -> impl Iterator<Item = StoreWrapper> + '_ { ... }
fn output_stores(
self,
graph: &Graph,
) -> impl Iterator<Item = StoreWrapper> + '_ { ... }
fn input_execution(
self,
graph: &Graph,
) -> impl Iterator<Item = NodeIndex> + '_ { ... }
fn output_execution(
self,
graph: &Graph,
) -> impl Iterator<Item = NodeIndex> + '_ { ... }
fn run_after(self, graph: &mut Graph, node: NodeIndex) { ... }
fn run_before(self, graph: &mut Graph, node: NodeIndex) { ... }
}Provided Methods
fn input_stores(self, graph: &Graph) -> impl Iterator<Item = StoreWrapper> + '_
fn output_stores(self, graph: &Graph) -> impl Iterator<Item = StoreWrapper> + '_
fn input_execution(self, graph: &Graph) -> impl Iterator<Item = NodeIndex> + '_
fn output_execution(self, graph: &Graph) -> impl Iterator<Item = NodeIndex> + '_
Sourcefn run_after(self, graph: &mut Graph, node: NodeIndex)
fn run_after(self, graph: &mut Graph, node: NodeIndex)
Adds an execution flow from the given node to this node.
Sourcefn run_before(self, graph: &mut Graph, node: NodeIndex)
fn run_before(self, graph: &mut Graph, node: NodeIndex)
Adds an execution flow from this node to the given node.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".